@@ -508,16 +508,12 @@ ical_attendees_from_props (icalcomponent *ical_comp, GSList *recipients, gboolea
 			icalproperty_add_parameter (prop, param);
 			/* PARTSTAT */
 			ui32 = (const uint32_t *) get_SPropValue(recip->out.all_lpProps, PR_RECIPIENT_TRACKSTATUS);
-			if (ui32) {
-				param = icalparameter_new_partstat (get_partstat_from_trackstatus (*ui32));
-				icalproperty_add_parameter (prop, param);
-			}
+			param = icalparameter_new_partstat (get_partstat_from_trackstatus (ui32 ? *ui32 : olResponseNone));
+			icalproperty_add_parameter (prop, param);
 			/* ROLE */
 			ui32 = (const uint32_t *) get_SPropValue(recip->out.all_lpProps, PR_RECIPIENT_TYPE);
-			if (ui32) {
-				param = icalparameter_new_role (get_role_from_type (*ui32));
-				icalproperty_add_parameter (prop, param);
-			}
+			param = icalparameter_new_role (get_role_from_type (ui32 ? *ui32 : olTo));
+			icalproperty_add_parameter (prop, param);
 #if 0
 			/* CALENDAR USER TYPE */
 			param = icalparameter_new_cutype ();
@@ -1663,8 +1659,8 @@ exchange_mapi_cal_util_build_props (struct SPropValue **value, struct SPropTagAr
 		e_cal_component_alarm_get_action (alarm, &action);
 		if (action == E_CAL_COMPONENT_ALARM_DISPLAY) {
 			ECalComponentAlarmTrigger trigger;
-			e_cal_component_alarm_get_trigger (alarm, &trigger);
 			int dur_int = 0; 
+			e_cal_component_alarm_get_trigger (alarm, &trigger);
 			switch (trigger.type) {
 			case E_CAL_COMPONENT_ALARM_TRIGGER_RELATIVE_START :
 				dur_int = (icaldurationtype_as_int (trigger.u.rel_duration)) / SECS_IN_MINUTE;
